@@ -1,10 +1,6 @@
 import stactools.core
 from stactools.cli.registry import Registry
 
-from stactools.fws_nwi.stac import create_collection, create_item
-
-__all__ = ["create_collection", "create_item"]
-
 stactools.core.use_fsspec()
 
 
@@ -14,4 +10,4 @@ def register_plugin(registry: Registry) -> None:
     registry.register_subcommand(commands.create_fwsnwi_command)
 
 
-__version__ = "0.1.0"
+__version__ = "0.2.0"
